#ifndef SPM_H
#define SPM_H

/* Gretag Spectrolino/Spectroscan command protocol
 *
 * Author: Neil Okamoto
 * Date: 1/9/2001
 *
 * Copyright 2001, DreamWorks LLC
 * All Rights Reserved.
 *
 * This material is licenced under the GNU GENERAL PUBLIC LICENCE :-
 * see the Licence.txt file for licencing details.
 */

/* Reference:
 * Gretag Spectrolino/Spectroscan Serial Interface, Edition 4
 */

/* Chapter 3. Spectrolino Communication Protocol */

#define SPM_CMD 0
#define SPM_REP 1

#define SPM_PROTO_NONE                            -1

#define SPM_PROTO_EXECMEASUREMENT				  0x20
#define SPM_PROTO_EXECREFMEASUREMENT			  0x22
#define SPM_PROTO_EXECWHITEMEASUREMENT			  0x21
#define SPM_PROTO_SETMEASUREMENTOUTPUT			  0xb1
#define SPM_PROTO_PARAMETERREQUEST				  0x00
#define SPM_PROTO_PARAMETERDOWNLOAD				  0x16
#define SPM_PROTO_SPECPARAMETERREQUEST			  0xb8
#define SPM_PROTO_SPECTRUMREQUEST				  0x05
#define SPM_PROTO_CPARAMETERREQUEST				  0xba
#define SPM_PROTO_CREQUEST						  0x06
#define SPM_PROTO_DENSITYPARAMETERREQUEST		  0xbc
#define SPM_PROTO_DENSITYREQUEST				  0x03
#define SPM_PROTO_DMAXREQUEST					  0x04
#define SPM_PROTO_WHITEREFERENCEREQUEST			  0xb3
#define SPM_PROTO_WHITEREFERENCEDOWNLOAD		  0xb7
#define SPM_PROTO_EXECWHITEREFTOORIGDAT			  0x4a
#define SPM_PROTO_MEASCONTROLDOWNLOAD			  0x4d
#define SPM_PROTO_MEASCONTROLREQUEST			  0x5b
#define SPM_PROTO_FLOATREQUEST					  0xc0
#define SPM_PROTO_FLOATDOWNLOAD					  0xc2
#define SPM_PROTO_ILLUMTABREQUEST				  0x38
#define SPM_PROTO_ILLUMTABDOWNLOAD				  0x3a
#define SPM_PROTO_GETVALNR						  0x47
#define SPM_PROTO_SETVALNR						  0x49
#define SPM_PROTO_SLOPEREQUEST					  0x01
#define SPM_PROTO_SLOPEDOWNLOAD					  0x17
#define SPM_PROTO_DENSTABREQUEST				  0x3b
#define SPM_PROTO_DENSTABDOWNLOAD				  0x3d
#define SPM_PROTO_DEVICEDATAREQUEST				  0xb5
#define SPM_PROTO_TARGETIDREQUEST				  0x2b
#define SPM_PROTO_NEWMEASUREREQUEST				  0x07
#define SPM_PROTO_NEWKEYREQUEST					  0x08
#define SPM_PROTO_TARGETONOFFSTDOWNLOAD			  0x33
#define SPM_PROTO_RESETSTATUSDOWNLOAD			  0x5a
#define SPM_PROTO_ACTERRORREQUEST				  0x29

#define SPM_PROTO_EXECERROR						  0x25
#define SPM_PROTO_DOWNLOADERROR					  0x1f
#define SPM_PROTO_PARAMETERANSWER				  0x0b
#define SPM_PROTO_SPECPARAMETERANSWER			  0xb9
#define SPM_PROTO_SPECTRUMANSWER				  0x10
#define SPM_PROTO_CPARAMETERANSWER				  0xbb
#define SPM_PROTO_CANSWER						  0x11
#define SPM_PROTO_DENSITYPARAMETERANSWER		  0xbd
#define SPM_PROTO_DENSITYANSWER					  0x0e
#define SPM_PROTO_DMAXANSWER					  0x0f
#define SPM_PROTO_WHITEREFERENCEANSWER			  0xb4
#define SPM_PROTO_MEASCONTROLANSWER				  0x5c
#define SPM_PROTO_FLOATANSWER					  0xc1
#define SPM_PROTO_ILLUMTABANSWER				  0x39
#define SPM_PROTO_VALNRANSWER					  0x48
#define SPM_PROTO_SLOPEANSWER					  0x0c
#define SPM_PROTO_DENSTABANSWER					  0x3c
#define SPM_PROTO_DEVICEDATAANSWER				  0xb6
#define SPM_PROTO_TARGETIDANSWER				  0x31
#define SPM_PROTO_NEWMEASUREANSWER				  0x12
#define SPM_PROTO_NEWKEYANSWER					  0x13
#define SPM_PROTO_COMERR						  0x26
#define SPM_PROTO_ACTERRORANSWER				  0x2f


/* Chapter 5. SpectroScan Communication Protocol */

#define SPM_PROTO_MOVEABSOLUT					  0xd000
#define SPM_PROTO_MOVERELATIVE					  0xd001
#define SPM_PROTO_MOVEHOME						  0xd002
#define SPM_PROTO_MOVEUP						  0xd003
#define SPM_PROTO_MOVEDOWN						  0xd004
#define SPM_PROTO_MOVETOWHITEREFPOS				  0xd006
#define SPM_PROTO_MOVEANDMEASURE				  0xd007
#define SPM_PROTO_OUTPUTACTUALPOSITION			  0xd005
#define SPM_PROTO_INITIALIZEDEVICE				  0xd00a
#define SPM_PROTO_SCANSPECTROLINO				  0xd00b
#define SPM_PROTO_INITMOTORPOSITION				  0xd00c
#define SPM_PROTO_SETDEVICEONLINE				  0xd010
#define SPM_PROTO_SETDEVICEOFFLINE				  0xd011
#define SPM_PROTO_HOLDPAPER						  0xd012
#define SPM_PROTO_RELEASEPAPER					  0xd013
#define SPM_PROTO_SETTABLEMODE					  0xd00d
#define SPM_PROTO_SETLIGHTLEVEL					  0xd00e
#define SPM_PROTO_SETTRANSMSTANDBYPOS			  0xd00f
#define SPM_PROTO_SETDIGITIZINGMODE				  0xd014
#define SPM_PROTO_OUTPUTDIGITIZEDVALUES			  0xd015
#define SPM_PROTO_CHANGEBAUDRATE				  0xd020
#define SPM_PROTO_CHANGEHANDSHAKE				  0xd021
#define SPM_PROTO_OUTPUTACTUALKEY				  0xd022
#define SPM_PROTO_OUTPUTLASTKEY					  0xd023
#define SPM_PROTO_OUTPUTSTATUS					  0xd024
#define SPM_PROTO_CLEARSTATUS					  0xd025
#define SPM_PROTO_SETKEYACKNOWLEDGEMODE			  0xd016
#define SPM_PROTO_RESETKEYACKNOWLEDGEMODE		  0xd017
#define SPM_PROTO_SETSPECIALSTATUS				  0xd026
#define SPM_PROTO_CLEARSPECIALSTATUS			  0xd027
#define SPM_PROTO_OUTPUTSPECIALSTATUS			  0xd028
#define SPM_PROTO_OUTPUTTYPE					  0xd030
#define SPM_PROTO_OUTPUTSERIALNUMBER			  0xd031
#define SPM_PROTO_OUTPUTARTICLENUMBER			  0xd032
#define SPM_PROTO_OUTPUTPRODUCTIONDATE			  0xd033
#define SPM_PROTO_OUTPUTSOFTWAREVERSION			  0xd034
#define SPM_PROTO_ERRORANSWER					  0xd180
#define SPM_PROTO_POSITIONANSWER				  0xd181
#define SPM_PROTO_KEYANSWER						  0xd182
#define SPM_PROTO_STATUSANSWER					  0xd183
#define SPM_PROTO_TYPEANSWER					  0xd190
#define SPM_PROTO_SERIALNUMBERANSWER			  0xd191
#define SPM_PROTO_ARTICLENUMBERANSWER			  0xd192
#define SPM_PROTO_PRODUCTIONDATEANSWER			  0xd193
#define SPM_PROTO_SOFTWAREVERSIONANSWER			  0xd194
#define SPM_PROTO_SSCOMERR						  0xd1a0


/* Chapter 6. All Communication Types */

#define SPM_ACTUALFILTER_NODEFINED				  0x00
#define SPM_ACTUALFILTER_NOFILTER				  0x01
#define SPM_ACTUALFILTER_POLFILTER				  0x02
#define SPM_ACTUALFILTER_D65FILTER				  0x03
#define SPM_ACTUALFILTER_UVCUTFILTER			  0x05
#define SPM_ACTUALFILTER_CUSTOMFILTER			  0x06

#define SPM_BAUDRATE_110						  0x00
#define SPM_BAUDRATE_150						  0x01
#define SPM_BAUDRATE_300						  0x02
#define SPM_BAUDRATE_600						  0x03
#define SPM_BAUDRATE_1200						  0x04
#define SPM_BAUDRATE_2400						  0x05
#define SPM_BAUDRATE_4800						  0x06
#define SPM_BAUDRATE_9600						  0x07
#define SPM_BAUDRATE_19200						  0x08
#define SPM_BAUDRATE_28800						  0x09
#define SPM_BAUDRATE_57600						  0x0a

#define SPM_COMFLOAT_VPHOTOMETRICYREF			  0x00

#define SPM_CONTROL_PROTOCOLWITHXONXOFF			  0x1e
#define SPM_CONTROL_PROTOCOLWITHOUTXONXOFF		  0x1f
#define SPM_CONTROL_PROTOCOLHARDWAREHS			  0xcf
#define SPM_CONTROL_SETBAUD110					  0x20
#define SPM_CONTROL_SETBAUD150					  0x21
#define SPM_CONTROL_SETBAUD300					  0x22
#define SPM_CONTROL_SETBAUD600					  0x23
#define SPM_CONTROL_SETBAUD1200					  0x24
#define SPM_CONTROL_SETBAUD2400					  0x25
#define SPM_CONTROL_SETBAUD4800					  0x26
#define SPM_CONTROL_SETBAUD9600					  0x27
#define SPM_CONTROL_SETBAUD19200				  0x28
#define SPM_CONTROL_SETBAUD28800				  0x98
#define SPM_CONTROL_SETBAUD57600				  0x99
#define SPM_CONTROL_SPEAKERON					  0x54
#define SPM_CONTROL_SPEAKEROFF					  0x55
#define SPM_CONTROL_REMISSIONMEAS				  0x9b
#define SPM_CONTROL_TRANSMISSIONMEAS			  0x9c
#define SPM_CONTROL_EMISSIONMEAS				  0x9d
#define SPM_CONTROL_PHOTOMETRICABSOLUTE			  0x9e
#define SPM_CONTROL_PHOTOMETRICRELATIVE			  0x9f
#define SPM_CONTROL_SETCUSTOMFILTER				  0xa0
#define SPM_CONTROL_RELEASECUSTOMFILTER			  0xa1

#define SPM_C_XYY								  0x00
#define SPM_C_LAB								  0x01
#define SPM_C_LCHAB								  0x02
#define SPM_C_LUV								  0x03
#define SPM_C_XYZ								  0x04
#define SPM_C_RXRYRZ							  0x05
#define SPM_C_HLAB								  0x06
#define SPM_C_LABMG								  0x0b
#define SPM_C_LCHMG								  0x0c
#define SPM_C_LCHUV								  0x0d

#define SPM_DENSITYFILTER_DB					  0x0
#define SPM_DENSITYFILTER_DC					  0x1
#define SPM_DENSITYFILTER_DM					  0x2
#define SPM_DENSITYFILTER_DY					  0x3
#define SPM_DENSITYFILTER_DMAX					  0x4
#define SPM_DENSITYFILTER_DAUTO					  0x5

#define SPM_DEVICE_SPM10						  0x00
#define SPM_DEVICE_SPM50						  0x01
#define SPM_DEVICE_SPM55						  0x02
#define SPM_DEVICE_SPM60						  0x03
#define SPM_DEVICE_SPM100						  0x04
#define SPM_DEVICE_SPM100II						  0x05
#define SPM_DEVICE_SPM100IILIB			   		  0x06
#define SPM_DEVICE_D196							  0x10
#define SPM_DEVICE_D19C							  0x11
#define SPM_DEVICE_D118C						  0x12
#define SPM_DEVICE_DM620						  0x13
#define SPM_DEVICE_SPECTROLINO					  0x20
#define SPM_DEVICE_VIDEOLINO					  0x30
#define SPM_DEVICE_SPECTROSCAN					  0x40

#define SPM_DSTD_ANSIA							  0x00
#define SPM_DSTD_ANSIT							  0x01
#define SPM_DSTD_DIN							  0x02
#define SPM_DSTD_DINNB							  0x03
#define SPM_DSTD_DS1							  0x08

#define SPM_DTCOMERR_DTCOMMNOERR				  0x00
#define SPM_DTCOMERR_STOPBUTNOSTART				  0x01
#define SPM_DTCOMERR_ILLEGALCHARINREC			  0x02
#define SPM_DTCOMERR_INCORRECTRECLEN			  0x03
#define SPM_DTCOMERR_ILLEGALRECTYPE				  0x04
#define SPM_DTCOMERR_NOTAGFIELD					  0x06
#define SPM_DTCOMERR_CONVERROR					  0x07
#define SPM_DTCOMERR_INVALFOREMISSION			  0x08
#define SPM_DTCOMERR_NOACCESS					  0x10

#define SPM_ERROR_NOERROR						  0x00
#define SPM_ERROR_MEMORYFAILURE					  0x01
#define SPM_ERROR_POWERFAILURE					  0x02
#define SPM_ERROR_LAMPFAILURE					  0x04
#define SPM_ERROR_HARDWAREFAILURE				  0x05
#define SPM_ERROR_FILTEROUTOFPOS				  0x06
#define SPM_ERROR_SENDTIMEOUT					  0x07
#define SPM_ERROR_DRIVEERROR					  0x08
#define SPM_ERROR_MEASDISABLED					  0x09
#define SPM_ERROR_DENSCALERROR					  0x0a
#define SPM_ERROR_EPROMFAILURE					  0x0d
#define SPM_ERROR_REMOVERFLOW					  0x0e
#define SPM_ERROR_MEMORYERROR					  0x10
#define SPM_ERROR_FULLMEMORY					  0x11
#define SPM_ERROR_WHITEMEASOK					  0x13
#define SPM_ERROR_NOTREADY						  0x15
#define SPM_ERROR_WHITEMEASWARN					  0x32
#define SPM_ERROR_RESETDONE						  0x33
#define SPM_ERROR_EMISSIONCALOK					  0x34
#define SPM_ERROR_ONLYEMISSION					  0x35
#define SPM_ERROR_CHECKSUMWRONG					  0x36
#define SPM_ERROR_NOVALIDMEAS					  0x37
#define SPM_ERROR_BACKUPERROR					  0x38
#define SPM_ERROR_PROGRAMROMERROR1				  0x39
#define SPM_ERROR_PROGRAMROMERROR2				  0x3a
#define SPM_ERROR_PROGRAMROMERROR3				  0x3b
#define SPM_ERROR_PROGRAMROMERROR4				  0x3c
#define SPM_ERROR_PROGRAMROMERROR5				  0x3d
#define SPM_ERROR_PROGRAMROMERROR6				  0x3e
#define SPM_ERROR_PROGRAMROMERROR7				  0x3f
#define SPM_ERROR_PROGRAMROMERROR8				  0x40

#define SPM_HANDSHAKE_NOHANDSHAKE				  0x00
#define SPM_HANDSHAKE_HANDSHAKEXONXOFF			  0x01
#define SPM_HANDSHAKE_HARDWAREHANDSHAKE			  0x02

#define SPM_ILLUM_ILLUMINANTA					  0x00
#define SPM_ILLUM_ILLUMINANTC					  0x01
#define SPM_ILLUM_ILLUMINANTD65					  0x02
#define SPM_ILLUM_ILLUMINANTD50					  0x03
#define SPM_ILLUM_IL1							  0x08
#define SPM_ILLUM_DXX1							  0x10
#define SPM_ILLUM_ILLUMINANTF1					  0x18
#define SPM_ILLUM_ILLUMINANTF2					  0x19
#define SPM_ILLUM_ILLUMINANTF3					  0x1a
#define SPM_ILLUM_ILLUMINANTF4					  0x1b
#define SPM_ILLUM_ILLUMINANTF5					  0x1c
#define SPM_ILLUM_ILLUMINANTF6					  0x1d
#define SPM_ILLUM_ILLUMINANTF7					  0x1e
#define SPM_ILLUM_ILLUMINANTF8					  0x1f
#define SPM_ILLUM_ILLUMINANTF9					  0x20
#define SPM_ILLUM_ILLUMINANTF10					  0x21
#define SPM_ILLUM_ILLUMINANTF11					  0x22
#define SPM_ILLUM_ILLUMINANTF12					  0x23

#define SPM_KEYSET_NOKEY						  0x0000
#define SPM_KEYSET_MEASUREMENTKEY				  0x8000

#define SPM_LIGHTLEVEL_ALLLIGHTSOFF				  0x00
#define SPM_LIGHTLEVEL_LIGHTSSTANDBY1			  0x01
#define SPM_LIGHTLEVEL_LIGHTSSTANDBY2			  0x02

#define SPM_MEASUREMENTMODE_NORMALMEAS			  0x00
#define SPM_MEASUREMENTMODE_WHITECALIBRATION	  0x01
#define SPM_MEASUREMENTMODE_WHITECALWITHWARN	  0x07
#define SPM_MEASUREMENTMODE_EMISSIONCAL			  0x08

#define SPM_NEWMEASUREMENT_NONEWMEAS			  0x00
#define SPM_NEWMEASUREMENT_NEWMEAS				  0x01
#define SPM_NEWMEASUREMENT_NEWWHITECAL			  0x02
#define SPM_NEWMEASUREMENT_NEWWHITECALWW		  0x03
#define SPM_NEWMEASUREMENT_NEWEMISSIONCAL		  0x04

#define SPM_OBSERVER_TWODEG						  0x00
#define SPM_OBSERVER_TENDEG						  0x01

#define SPM_ORIGINALWHITEREF_ORIGINALWHITEREF	  0x00
#define SPM_ORIGINALWHITEREF_USERWHITEREF		  0x01
#define SPM_ORIGINALWHITEREF_NOTDEFWHITEREF		  0x02

#define SPM_OUTPUTSET_PARAMETER					  0x00
#define   SPM_OUTPUTPARAMETERSET_DSTDTYPE		  0x01
#define   SPM_OUTPUTPARAMETERSET_WBASE			  0x02
#define   SPM_OUTPUTPARAMETERSET_ILLUMINANT		  0x04
#define   SPM_OUTPUTPARAMETERSET_OBSERVER		  0x08
#define   SPM_OUTPUTPARAMETERSET_ACTUALFILTER	  0x10
#define SPM_OUTPUTSET_SPECTRUM					  0x01
#define   SPM_OUTPUTSPECTRUMSET_SPECTRUM		  0x01
#define   SPM_OUTPUTSPECTRUMSET_DENSITYSPECTRUM	  0x02
#define SPM_OUTPUTSET_CMETRY1					  0x02
#define   SPM_OUTPUTCMETRY1SET_XYY				  0x01
#define   SPM_OUTPUTCMETRY1SET_LAB				  0x02
#define   SPM_OUTPUTCMETRY1SET_LCHAB			  0x04
#define   SPM_OUTPUTCMETRY1SET_LUV				  0x08
#define   SPM_OUTPUTCMETRY1SET_XYZ				  0x10
#define   SPM_OUTPUTCMETRY1SET_RXRYRZ			  0x20
#define   SPM_OUTPUTCMETRY1SET_HLAB				  0x40
#define SPM_OUTPUTSET_CMETRY2					  0x03
#define   SPM_OUTPUTCMETRY2SET_LABMG			  0x01
#define   SPM_OUTPUTCMETRY2SET_LCHMG			  0x02
#define   SPM_OUTPUTCMETRY2SET_LCHUV			  0x04
#define SPM_OUTPUTSET_DENSITY					  0x04
#define   SPM_OUTPUTDENSITYSET_DENSITYBLACK		  0x01
#define   SPM_OUTPUTDENSITYSET_DENSITYCYAN		  0x02
#define   SPM_OUTPUTDENSITYSET_DENSITYMAGENTA	  0x04
#define   SPM_OUTPUTDENSITYSET_DENSITYYELLOW	  0x08
#define   SPM_OUTPUTDENSITYSET_DENSITYMAX		  0x10
#define   SPM_OUTPUTDENSITYSET_DENSITYAUTO		  0x20
#define SPM_OUTPUTSET_ERRORTYPE					  0xff

#define SPM_PRESSTIME_SHORT						  0x00
#define SPM_PRESSTIME_LONG						  0x01

#define SPM_REFERENCE_SENSOR					  0x00
#define SPM_REFERENCE_SIGHT						  0x01

#define SPM_REMOTEERROR_NOERROR					  0x0000
#define SPM_REMOTEERROR_SLOPEOUTOFRANGE			  0x0001
#define SPM_REMOTEERROR_DORLOUTOFRANGE			  0x0002
#define SPM_REMOTEERROR_REFLECTANCEOUTOFRANGE	  0x0004
#define SPM_REMOTEERROR_COLOR1OUTOFRANGE		  0x0008
#define SPM_REMOTEERROR_COLOR2OUTOFRANGE		  0x0010
#define SPM_REMOTEERROR_COLOR3OUTOFRANGE		  0x0020
#define SPM_REMOTEERROR_NOTANSRORBOOLEAN		  0x0040
#define SPM_REMOTEERROR_NOVALIDVALORREF			  0x0080
#define SPM_REMOTEERROR_NOVALIDDSTD				  0x0100
#define SPM_REMOTEERROR_NOVALIDWHITE			  0x0200
#define SPM_REMOTEERROR_NOVALIDILLUM			  0x0400
#define SPM_REMOTEERROR_NOVALIDOBSERVER			  0x0800
#define SPM_REMOTEERROR_NOVALIDMAXLAMBDA		  0x1000
#define SPM_REMOTEERROR_NOVALIDSPECT			  0x2000
#define SPM_REMOTEERROR_NOVALIDCOLSYSORINDEX	  0x4000
#define SPM_REMOTEERROR_NOVALIDCHAR				  0x8000

#define SPM_SCANERROR_NOERROR					  0x00
#define SPM_SCANERROR_DEVICEISOFFLINE			  0x01
#define SPM_SCANERROR_OUTOFRANGE				  0x02
#define SPM_SCANERROR_PROGRAMMINGERROR			  0x03
#define SPM_SCANERROR_NOUSERACCESS				  0x04
#define SPM_SCANERROR_NOVALIDCOMMAND			  0x05
#define SPM_SCANERROR_NODEVICEFOUND				  0x06
#define SPM_SCANERROR_MEASUREMENTERROR			  0x07
#define SPM_SCANERROR_NOTRANSMTABLE				  0x08
#define SPM_SCANERROR_NOTINTRANSMMODE			  0x09
#define SPM_SCANERROR_NOTINREFLECTMODE			  0x0a

#define SPM_SCANKEY_ENTER						  0x01
#define SPM_SCANKEY_PAPER						  0x02
#define SPM_SCANKEY_ONLINE						  0x04
#define SPM_SCANKEY_UPDOWN						  0x08
#define SPM_SCANKEY_MOVERIGHT					  0x10
#define SPM_SCANKEY_MOVELEFT					  0x20
#define SPM_SCANKEY_MOVEDOWN					  0x40
#define SPM_SCANKEY_MOVEUP						  0x80

#define SPM_SPECIALSTATUS_HEADDWNONMOVE			  0x01
#define SPM_SPECIALSTATUS_TABLEINTRANSMODE		  0x10
#define SPM_SPECIALSTATUS_ALLLIGHTSON			  0x20

#define SPM_SPECT_RS							  0x00
#define SPM_SPECT_DS							  0x01

#define SPM_STATUSMODE_INITALL					  0x00
#define SPM_STATUSMODE_INITWITHOUTREMOTE		  0x05

#define SPM_STATUSSET_ENTERKEYPRESSED			  0x01
#define SPM_STATUSSET_DEVICEISONLINE			  0x10
#define SPM_STATUSSET_DIGITIZINGMODEON			  0x20
#define SPM_STATUSSET_KEYACKMODEON				  0x40
#define SPM_STATUSSET_PAPERISHELD				  0x80

#define SPM_TABLEMODE_REFLECTANCE				  0x00
#define SPM_TABLEMODE_TRANSMISSION				  0x01

#define SPM_TABVALUE_VDXX1						  0x60

#define SPM_TARGETTECH_SPM						  0x00
#define SPM_TARGETTECH_D190						  0x01
#define SPM_TARGETTECH_SPECTROLINO				  0x02
#define SPM_TARGETTECH_VIDEOLINO				  0x03
#define SPM_TARGETTECH_SPECTROSCAN				  0x04

#define SPM_WBASE_PAP							  0x00
#define SPM_WBASE_ABS							  0x01

#define SPM_WHITEREFPOS_REFTILE1				  0x00
#define SPM_WHITEREFPOS_REFTILE2				  0x01

#define SPM_ZCOORD_SENSORUP						  0x00
#define SPM_ZCOORD_SENSORDOWN					  0x01



/* SPM library public API */

#include "stdarg.h"

extern int   spm_command (char *buf, int cmd,   ...);
extern int   spm_commandv(char *buf, int cmd,   va_list *ap);
extern int   spm_reply   (char *buf, int reply, ...);
extern int   spm_replyv  (char *buf, int reply, va_list *ap);
extern int   spm_reply_type(char *buf);
extern char* spm_cmdname(int cmd);
extern int   spm_expect_reply(int cmd);
extern int   spm_timeout(int cmd);

#endif
